This software is developed as a universal aerospace engineering toolbox.
This software is still under development and also includes third-party codes.
If you want to contribute please contact the author Lukas Müller.